@@ -4,7 +4,7 @@
  * Copyright (C) 2014, Hans-Peter Deifel <hpdeifel@gmx.de>
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
  * Copyright (C) 2018, Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
- * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
+ * Copyright (C) 2018, 2020 Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2018 Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2018, Zsombor Hollay-Horvath <hollay.horvath@gmail.com>
  *
@@ -47,7 +47,7 @@ namespace detail
 
 extern debug_func user_debug_function;
 extern void *debug_closure;
-void error_function(void *data, ErrorCategory category, Goffset pos, const char *msg);
+void error_function(ErrorCategory category, Goffset pos, const char *msg);
 
 rectf pdfrectangle_to_rectf(const PDFRectangle &pdfrect);
 
