@@ -14,6 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2016 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2019 Volker Krause <vkrause@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -22,7 +23,7 @@
 
 #include <config.h>
 
-#include <stdlib.h>
+#include <cstdlib>
 #include "FoFiEncodings.h"
 
 //------------------------------------------------------------------------
@@ -945,7 +946,7 @@ const char *fofiType1CStdStrings[391] = {
   "Semibold"
 };
 
-unsigned short fofiType1CISOAdobeCharset[229] = {
+const unsigned short fofiType1CISOAdobeCharset[229] = {
     0,   1,   2,   3,   4,   5,   6,   7,   8,   9,
    10,  11,  12,  13,  14,  15,  16,  17,  18,  19,
    20,  21,  22,  23,  24,  25,  26,  27,  28,  29,
@@ -971,7 +972,7 @@ unsigned short fofiType1CISOAdobeCharset[229] = {
   220, 221, 222, 223, 224, 225, 226, 227, 228
 };
 
-unsigned short fofiType1CExpertCharset[166] = {
+const unsigned short fofiType1CExpertCharset[166] = {
     0,   1, 229, 230, 231, 232, 233, 234, 235, 236,
   237, 238,  13,  14,  15,  99, 239, 240, 241, 242,
   243, 244, 245, 246, 247, 248,  27,  28, 249, 250,
@@ -991,7 +992,7 @@ unsigned short fofiType1CExpertCharset[166] = {
   373, 374, 375, 376, 377, 378
 };
 
-unsigned short fofiType1CExpertSubsetCharset[87] = {
+const unsigned short fofiType1CExpertSubsetCharset[87] = {
     0,   1, 231, 232, 235, 236, 237, 238,  13,  14,
    15,  99, 239, 240, 241, 242, 243, 244, 245, 246,
   247, 248,  27,  28, 249, 250, 251, 253, 254, 255,
