@@ -27,9 +27,9 @@
 
 #include <config.h>
 
-#include <stdlib.h>
-#include <string.h>
-#include <limits.h>
+#include <cstdlib>
+#include <cstring>
+#include <climits>
 #include "goo/glibc.h"
 #include "goo/gmem.h"
 #include "goo/GooLikely.h"
@@ -277,7 +277,7 @@ void FoFiType1::parse() {
 	}
 	for (p = buf; *p == ' ' || *p == '\t'; ++p) ;
 	if (!strncmp(p, "dup", 3)) {
-	  while (1) {
+	  while (true) {
 	    p += 3;
 	    for (; *p == ' ' || *p == '\t'; ++p) ;
 	    code = 0;
@@ -366,15 +366,15 @@ void FoFiType1::parse() {
 // Undo the PFB encoding, i.e., remove the PFB headers.
 void FoFiType1::undoPFB() {
   bool ok;
-  Guchar *file2;
+  unsigned char *file2;
   int pos1, pos2, type;
-  Guint segLen;
+  unsigned int segLen;
 
   ok = true;
   if (getU8(0, &ok) != 0x80 || !ok) {
     return;
   }
-  file2 = (Guchar *)gmalloc(len);
+  file2 = (unsigned char *)gmalloc(len);
   pos1 = pos2 = 0;
   while (getU8(pos1, &ok) == 0x80 && ok) {
     type = getU8(pos1 + 1, &ok);
