@@ -19,8 +19,9 @@
 
 #include "config.h"
 
-#include <errno.h>
-#include <glib/gstdio.h>
+#include <cerrno>
+
+#include <goo/gfile.h>
 
 #include "poppler-media.h"
 #include "poppler-private.h"
@@ -214,7 +215,7 @@ poppler_media_save (PopplerMedia *poppler_media,
   g_return_val_if_fail (POPPLER_IS_MEDIA (poppler_media), FALSE);
   g_return_val_if_fail (poppler_media->stream.isStream(), FALSE);
 
-  f = g_fopen (filename, "wb");
+  f = openFile (filename, "wb");
 
   if (f == nullptr)
     {
