@@ -27,6 +27,7 @@
 // Copyright (C) 2013, 2017 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
 // Copyright (C) 2018 Mojca Miklavec <mojca@macports.org>
+// Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -36,23 +37,14 @@
 #include <config.h>
 
 #ifndef _WIN32
-#  if defined(MACOS)
-#    include <sys/stat.h>
-#  elif !defined(ACORN)
-#    include <sys/types.h>
-#    include <sys/stat.h>
-#    include <fcntl.h>
-#  endif
-#  include <limits.h>
-#  include <string.h>
-#  if !defined(VMS) && !defined(ACORN) && !defined(MACOS)
-#    include <pwd.h>
-#  endif
-#  if defined(VMS) && (__DECCXX_VER < 50200000)
-#    include <unixlib.h>
-#  endif
+#  include <sys/types.h>
+#  include <sys/stat.h>
+#  include <fcntl.h>
+#  include <climits>
+#  include <cstring>
+#  include <pwd.h>
 #endif // _WIN32
-#include <stdio.h>
+#include <cstdio>
 #include <limits>
 #include "GooString.h"
 #include "gfile.h"
@@ -66,6 +58,8 @@
 
 #ifndef _WIN32
 
+using namespace std::string_literals;
+
 namespace {
 
 template< typename... >
@@ -105,47 +99,7 @@ inline const struct timespec& mtim(const struct stat& stbuf) {
 //------------------------------------------------------------------------
 
 GooString *appendToPath(GooString *path, const char *fileName) {
-#if defined(VMS)
-  //---------- VMS ----------
-  //~ this should handle everything necessary for file
-  //~ requesters, but it's certainly not complete
-  char *p0, *p1, *p2;
-  char *q1;
-
-  p0 = path->c_str();
-  p1 = p0 + path->getLength() - 1;
-  if (!strcmp(fileName, "-")) {
-    if (*p1 == ']') {
-      for (p2 = p1; p2 > p0 && *p2 != '.' && *p2 != '['; --p2) ;
-      if (*p2 == '[')
-	++p2;
-      path->del(p2 - p0, p1 - p2);
-    } else if (*p1 == ':') {
-      path->append("[-]");
-    } else {
-      path->clear();
-      path->append("[-]");
-    }
-  } else if ((q1 = strrchr(fileName, '.')) && !strncmp(q1, ".DIR;", 5)) {
-    if (*p1 == ']') {
-      path->insert(p1 - p0, '.');
-      path->insert(p1 - p0 + 1, fileName, q1 - fileName);
-    } else if (*p1 == ':') {
-      path->append('[');
-      path->append(']');
-      path->append(fileName, q1 - fileName);
-    } else {
-      path->clear();
-      path->append(fileName, q1 - fileName);
-    }
-  } else {
-    if (*p1 != ']' && *p1 != ':')
-      path->clear();
-    path->append(fileName);
-  }
-  return path;
-
-#elif defined(_WIN32)
+#ifdef _WIN32
   //---------- Win32 ----------
   GooString *tmp;
   char buf[256];
@@ -160,80 +114,6 @@ GooString *appendToPath(GooString *path, const char *fileName) {
   path->append(buf);
   return path;
 
-#elif defined(ACORN)
-  //---------- RISCOS ----------
-  char *p;
-  int i;
-
-  path->append(".");
-  i = path->getLength();
-  path->append(fileName);
-  for (p = path->c_str() + i; *p; ++p) {
-    if (*p == '/') {
-      *p = '.';
-    } else if (*p == '.') {
-      *p = '/';
-    }
-  }
-  return path;
-
-#elif defined(MACOS)
-  //---------- MacOS ----------
-  char *p;
-  int i;
-
-  path->append(":");
-  i = path->getLength();
-  path->append(fileName);
-  for (p = path->c_str() + i; *p; ++p) {
-    if (*p == '/') {
-      *p = ':';
-    } else if (*p == '.') {
-      *p = ':';
-    }
-  }
-  return path;
-
-#elif defined(__EMX__)
-  //---------- OS/2+EMX ----------
-  int i;
-
-  // appending "." does nothing
-  if (!strcmp(fileName, "."))
-    return path;
-
-  // appending ".." goes up one directory
-  if (!strcmp(fileName, "..")) {
-    for (i = path->getLength() - 2; i >= 0; --i) {
-      if (path->getChar(i) == '/' || path->getChar(i) == '\\' ||
-	  path->getChar(i) == ':')
-	break;
-    }
-    if (i <= 0) {
-      if (path->getChar(0) == '/' || path->getChar(0) == '\\') {
-	path->del(1, path->getLength() - 1);
-      } else if (path->getLength() >= 2 && path->getChar(1) == ':') {
-	path->del(2, path->getLength() - 2);
-      } else {
-	path->clear();
-	path->append("..");
-      }
-    } else {
-      if (path->getChar(i-1) == ':')
-	++i;
-      path->del(i, path->getLength() - i);
-    }
-    return path;
-  }
-
-  // otherwise, append "/" and new path component
-  if (path->getLength() > 0 &&
-      path->getChar(path->getLength() - 1) != '/' &&
-      path->getChar(path->getLength() - 1) != '\\')
-    path->append('/');
-  path->append(fileName);
-  return path;
-
 #else
   //---------- Unix ----------
   int i;
@@ -270,6 +150,39 @@ GooString *appendToPath(GooString *path, const char *fileName) {
 #endif
 }
 
+static bool makeFileDescriptorCloexec(int fd) {
+#ifdef FD_CLOEXEC
+  int flags = fcntl(fd, F_GETFD);
+  if (flags >= 0 && !(flags & FD_CLOEXEC))
+    flags = fcntl(fd, F_SETFD, flags | FD_CLOEXEC);
+
+  return flags >= 0;
+#else
+  return true;
+#endif
+}
+
+#ifndef _WIN32
+
+int openFileDescriptor(const char *path, int flags) {
+#ifdef O_CLOEXEC
+  return open(path, flags | O_CLOEXEC);
+#else
+  int fd = open(path, flags);
+  if (fd == -1)
+    return fd;
+
+  if (!makeFileDescriptorCloexec(fd)) {
+    close(fd);
+    return -1;
+  }
+
+  return fd;
+#endif
+}
+
+#endif
+
 FILE *openFile(const char *path, const char *mode) {
 #ifdef _WIN32
   OSVERSIONINFO version;
@@ -329,7 +242,23 @@ FILE *openFile(const char *path, const char *mode) {
     return fopen(nPath, mode);
   }
 #else
-  return fopen(path, mode);
+  // First try to atomically open the file with CLOEXEC
+  const std::string modeStr = mode + "e"s;
+  FILE *file = fopen(path, modeStr.c_str());
+  if (file != nullptr)
+    return file;
+
+  // Fall back to the provided mode and apply CLOEXEC afterwards
+  file = fopen(path, mode);
+  if (file == nullptr)
+    return nullptr;
+
+  if (!makeFileDescriptorCloexec(fileno(file))) {
+    fclose(file);
+    return nullptr;
+  }
+
+  return file;
 #endif
 }
 
@@ -482,11 +411,7 @@ Goffset GooFile::size() const {
 }
 
 GooFile* GooFile::open(const GooString *fileName) {
-#ifdef VMS
-  int fd = ::open(fileName->c_str(), Q_RDONLY, "ctx=stm");
-#else
-  int fd = ::open(fileName->c_str(), O_RDONLY);
-#endif
+  int fd = openFileDescriptor(fileName->c_str(), O_RDONLY);
   
   return fd < 0 ? nullptr : new GooFile(fd);
 }
@@ -514,11 +439,8 @@ bool GooFile::modificationTimeChangedSinceOpen() const
 //------------------------------------------------------------------------
 
 GDirEntry::GDirEntry(const char *dirPath, const char *nameA, bool doStat) {
-#ifdef VMS
-  char *p;
-#elif defined(_WIN32)
+#ifdef _WIN32
   DWORD fa;
-#elif defined(ACORN)
 #else
   struct stat st;
 #endif
@@ -528,19 +450,12 @@ GDirEntry::GDirEntry(const char *dirPath, const char *nameA, bool doStat) {
   fullPath = new GooString(dirPath);
   appendToPath(fullPath, nameA);
   if (doStat) {
-#ifdef VMS
-    if (!strcmp(nameA, "-") ||
-	((p = strrchr(nameA, '.')) && !strncmp(p, ".DIR;", 5)))
-      dir = true;
-#elif defined(ACORN)
-#else
 #ifdef _WIN32
     fa = GetFileAttributesA(fullPath->c_str());
     dir = (fa != 0xFFFFFFFF && (fa & FILE_ATTRIBUTE_DIRECTORY));
 #else
     if (stat(fullPath->c_str(), &st) == 0)
       dir = S_ISDIR(st.st_mode);
-#endif
 #endif
   }
 }
@@ -553,32 +468,25 @@ GDirEntry::~GDirEntry() {
 GDir::GDir(const char *name, bool doStatA) {
   path = new GooString(name);
   doStat = doStatA;
-#if defined(_WIN32)
+#ifdef _WIN32
   GooString *tmp;
 
   tmp = path->copy();
   tmp->append("/*.*");
   hnd = FindFirstFileA(tmp->c_str(), &ffd);
   delete tmp;
-#elif defined(ACORN)
-#elif defined(MACOS)
 #else
   dir = opendir(name);
-#ifdef VMS
-  needParent = strchr(name, '[') != NULL;
-#endif
 #endif
 }
 
 GDir::~GDir() {
   delete path;
-#if defined(_WIN32)
+#ifdef _WIN32
   if (hnd != INVALID_HANDLE_VALUE) {
     FindClose(hnd);
     hnd = INVALID_HANDLE_VALUE;
   }
-#elif defined(ACORN)
-#elif defined(MACOS)
 #else
   if (dir)
     closedir(dir);
@@ -588,7 +496,7 @@ GDir::~GDir() {
 GDirEntry *GDir::getNextEntry() {
   GDirEntry *e = nullptr;
 
-#if defined(_WIN32)
+#ifdef _WIN32
   if (hnd != INVALID_HANDLE_VALUE) {
     e = new GDirEntry(path->c_str(), ffd.cFileName, doStat);
     if (!FindNextFileA(hnd, &ffd)) {
@@ -596,21 +504,6 @@ GDirEntry *GDir::getNextEntry() {
       hnd = INVALID_HANDLE_VALUE;
     }
   }
-#elif defined(ACORN)
-#elif defined(MACOS)
-#elif defined(VMS)
-  struct dirent *ent;
-  if (dir) {
-    if (needParent) {
-      e = new GDirEntry(path->c_str(), "-", doStat);
-      needParent = false;
-      return e;
-    }
-    ent = readdir(dir);
-    if (ent) {
-      e = new GDirEntry(path->c_str(), ent->d_name, doStat);
-    }
-  }
 #else
   struct dirent *ent;
   if (dir) {
@@ -637,13 +530,8 @@ void GDir::rewind() {
   tmp->append("/*.*");
   hnd = FindFirstFileA(tmp->c_str(), &ffd);
   delete tmp;
-#elif defined(ACORN)
-#elif defined(MACOS)
 #else
   if (dir)
     rewinddir(dir);
-#ifdef VMS
-  needParent = strchr(path->c_str(), '[') != NULL;
-#endif
 #endif
 }
