@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005-2013, 2015, 2017-2019 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005-2013, 2015, 2017-2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Jeff Muizelaar <jrmuizel@nit.ca>
 // Copyright (C) 2005 Jonathan Blandford <jrb@redhat.com>
 // Copyright (C) 2005 Marco Pesenti Gritti <mpg@redhat.com>
@@ -35,6 +35,7 @@
 // Copyright (C) 2016 Masamichi Hosoda <trueroad@trueroad.jp>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2020 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -101,9 +102,9 @@ Catalog::Catalog(PDFDoc *docA) {
   acroForm = catDict.dictLookup("AcroForm");
 
   // read base URI
-  Object obj = catDict.dictLookup("URI");
+  Object obj = catDict.getDict()->lookupEnsureEncryptedIfNeeded("URI");
   if (obj.isDict()) {
-    Object obj2 = obj.dictLookup("Base");
+    Object obj2 = obj.getDict()->lookupEnsureEncryptedIfNeeded("Base");
     if (obj2.isString()) {
       baseURI = obj2.getString()->copy();
     }
@@ -337,7 +338,7 @@ int Catalog::findPage(const Ref pageRef) {
   return 0;
 }
 
-LinkDest *Catalog::findDest(const GooString *name) {
+std::unique_ptr<LinkDest> Catalog::findDest(const GooString *name) {
   // try named destination dictionary then name tree
   if (getDests()->isDict()) {
     Object obj1 = getDests()->dictLookup(name->c_str());
@@ -349,23 +350,22 @@ LinkDest *Catalog::findDest(const GooString *name) {
   return createLinkDest(&obj2);
 }
 
-LinkDest *Catalog::createLinkDest(Object *obj)
+std::unique_ptr<LinkDest> Catalog::createLinkDest(Object *obj)
 {
-  LinkDest *dest = nullptr;
+  std::unique_ptr<LinkDest> dest;
   if (obj->isArray()) {
-    dest = new LinkDest(obj->getArray());
+    dest = std::make_unique<LinkDest>(obj->getArray());
   } else if (obj->isDict()) {
     Object obj2 = obj->dictLookup("D");
     if (obj2.isArray())
-      dest = new LinkDest(obj2.getArray());
+      dest = std::make_unique<LinkDest>(obj2.getArray());
     else
       error(errSyntaxWarning, -1, "Bad named destination value");
   } else {
     error(errSyntaxWarning, -1, "Bad named destination value");
   }
   if (dest && !dest->isOk()) {
-    delete dest;
-    dest = nullptr;
+    dest.reset();
   }
 
   return dest;
@@ -393,7 +393,7 @@ const char *Catalog::getDestsName(int i)
   return obj->dictGetKey(i);
 }
 
-LinkDest *Catalog::getDestsDest(int i)
+std::unique_ptr<LinkDest> Catalog::getDestsDest(int i)
 {
   Object *obj = getDests();
   if (!obj->isDict()) {
@@ -403,7 +403,7 @@ LinkDest *Catalog::getDestsDest(int i)
   return createLinkDest(&obj1);
 }
 
-LinkDest *Catalog::getDestNameTreeDest(int i)
+std::unique_ptr<LinkDest> Catalog::getDestNameTreeDest(int i)
 {
   Object obj;
 
@@ -1074,8 +1074,7 @@ NameTree *Catalog::getJSNameTree()
   return jsNameTree;
 }
 
-LinkAction* Catalog::getAdditionalAction(DocumentAdditionalActionsType type) {
-  LinkAction *linkAction = nullptr;
+std::unique_ptr<LinkAction> Catalog::getAdditionalAction(DocumentAdditionalActionsType type) {
   Object additionalActionsObject = additionalActions.fetch(doc->getXRef());
   if (additionalActionsObject.isDict()) {
     const char *key = (type == actionCloseDocument ?       "WC" :
@@ -1086,7 +1085,7 @@ LinkAction* Catalog::getAdditionalAction(DocumentAdditionalActionsType type) {
 
     Object actionObject = additionalActionsObject.dictLookup(key);
     if (actionObject.isDict())
-      linkAction = LinkAction::parseAction(&actionObject, doc->getCatalog()->getBaseURI());
+      return LinkAction::parseAction(&actionObject, doc->getCatalog()->getBaseURI());
   }
-  return linkAction;
+  return nullptr;
 }
