@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005, 2007, 2009-2011, 2013, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007, 2009-2011, 2013, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Jonathan Blandford <jrb@redhat.com>
 // Copyright (C) 2005, 2006, 2008 Brad Hards <bradh@frogmouth.net>
 // Copyright (C) 2007 Julien Rebetez <julienr@svn.gnome.org>
@@ -28,6 +28,7 @@
 // Copyright (C) 2016 Masamichi Hosoda <trueroad@trueroad.jp>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2020 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -39,6 +40,7 @@
 
 #include "poppler-config.h"
 #include "Object.h"
+#include "Link.h"
 
 #include <vector>
 #include <memory>
@@ -49,8 +51,6 @@ class Object;
 class Page;
 class PageAttrs;
 struct Ref;
-class LinkDest;
-class LinkAction;
 class PageLabelInfo;
 class Form;
 class OCGs;
@@ -83,7 +83,6 @@ private:
     ~Entry();
     GooString name;
     Object value;
-    void free();
     static int cmpEntry(const void *voidEntry, const void *voidOtherEntry);
     static int cmp(const void *key, const void *entry);
   };
@@ -92,7 +91,6 @@ private:
   void addEntry(Entry *entry);
 
   XRef *xref;
-  Object *root;
   Entry **entries;
   int size, length; // size is the number of entries in
                     // the array of Entry*
@@ -148,11 +146,11 @@ public:
 
   // Find a page, given its object ID.  Returns page number, or 0 if
   // not found.
-  int findPage(int num, int gen);
+  int findPage(const Ref pageRef);
 
   // Find a named destination.  Returns the link destination, or
   // NULL if <name> is not a destination.
-  LinkDest *findDest(const GooString *name);
+  std::unique_ptr<LinkDest> findDest(const GooString *name);
 
   Object *getDests();
 
@@ -163,7 +161,7 @@ public:
   const char *getDestsName(int i);
 
   // Get the i'th named destination link destination in name-dict
-  LinkDest *getDestsDest(int i);
+  std::unique_ptr<LinkDest> getDestsDest(int i);
 
   // Get the number of named destinations in name-tree
   int numDestNameTree() { return getDestNameTree()->numEntries(); }
@@ -172,7 +170,7 @@ public:
   GooString *getDestNameTreeName(int i) { return getDestNameTree()->getName(i); }
 
   // Get the i'th named destination link destination in name-tree
-  LinkDest *getDestNameTreeDest(int i);
+  std::unique_ptr<LinkDest> getDestNameTreeDest(int i);
 
   // Get the number of embedded files
   int numEmbeddedFiles() { return getEmbeddedFileNameTree()->numEntries(); }
@@ -180,6 +178,14 @@ public:
   // Get the i'th file embedded (at the Document level) in the document
   FileSpec *embeddedFile(int i);
 
+  // Is there an embedded file with the given name?
+  bool hasEmbeddedFile(const std::string &fileName);
+
+  // Adds and embeddedFile
+  // If there is already an existing embedded file with the given fileName
+  // it gets replaced, if that's not what you want check hasEmbeddedFile first
+  void addEmbeddedFile(GooFile *file, const std::string &fileName);
+
   // Get the number of javascript scripts
   int numJS() { return getJSNameTree()->numEntries(); }
   GooString *getJSName(int i) { return getJSNameTree()->getName(i); }
@@ -241,7 +247,7 @@ public:
     actionPrintDocumentFinish,  ///< Performed after printing the document
   };
 
-  LinkAction *getAdditionalAction(DocumentAdditionalActionsType type);
+  std::unique_ptr<LinkAction> getAdditionalAction(DocumentAdditionalActionsType type);
 
 private:
 
@@ -284,7 +290,7 @@ private:
   NameTree *getDestNameTree();
   NameTree *getEmbeddedFileNameTree();
   NameTree *getJSNameTree();
-  LinkDest *createLinkDest(Object *obj);
+  std::unique_ptr<LinkDest> createLinkDest(Object *obj);
 
   mutable std::recursive_mutex mutex;
 };
