@@ -18,7 +18,7 @@
 // Copyright 2018 Andre Heinecke <aheinecke@intevation.de>
 // Copyright 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright 2018 Chinmoy Ranjan Pradhan <chinmoyrp65@protonmail.com>
-// Copyright 2019 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright 2019, 2020 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright 2019 João Netto <joaonetto901@gmail.com>
 //
 //========================================================================
@@ -119,7 +119,7 @@ public:
   void setReadOnly(bool value);
 
   LinkAction *getActivationAction(); // The caller should not delete the result
-  LinkAction *getAdditionalAction(Annot::FormAdditionalActionsType type); // The caller should delete the result
+  std::unique_ptr<LinkAction> getAdditionalAction(Annot::FormAdditionalActionsType type);
   bool setAdditionalAction(Annot::FormAdditionalActionsType t, const GooString &js);
 
   // return the unique ID corresponding to pageNum/fieldNum
