@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2007-2010, 2012, 2015, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2010, 2012, 2015, 2017-2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Jonathan Blandford <jrb@redhat.com>
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
@@ -26,7 +26,7 @@
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2013 Jason Crain <jason@aquaticape.us>
-// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2018, 2020 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
@@ -37,11 +37,12 @@
 #ifndef GLOBALPARAMS_H
 #define GLOBALPARAMS_H
 
-#include <assert.h>
+#include <cassert>
 #include "poppler-config.h"
-#include <stdio.h>
+#include <cstdio>
 #include "CharTypes.h"
 #include "UnicodeMap.h"
+#include "Error.h"
 #include <unordered_map>
 #include <string>
 #include <memory>
@@ -55,7 +56,6 @@ class CharCodeToUnicodeCache;
 class UnicodeMapCache;
 class CMap;
 class CMapCache;
-struct XpdfSecurityHandler;
 class GlobalParams;
 class GfxFont;
 class Stream;
@@ -88,12 +88,6 @@ enum PSLevel {
 
 //------------------------------------------------------------------------
 
-enum EndOfLineKind {
-  eolUnix,			// LF
-  eolDOS,			// CR+LF
-  eolMac			// CR
-};
-
 //------------------------------------------------------------------------
 
 class GlobalParams {
@@ -107,11 +101,11 @@ public:
   GlobalParams(const GlobalParams &) = delete;
   GlobalParams& operator=(const GlobalParams &) = delete;
 
-  void setupBaseFonts(char *dir);
+  void setupBaseFonts(const char *dir);
 
   //----- accessors
 
-  CharCode getMacRomanCharCode(char *charName);
+  CharCode getMacRomanCharCode(const char *charName);
 
   // Return Unicode values for character names.  Used for general text
   // extraction.
@@ -121,43 +115,39 @@ public:
   // lookups or text extraction with ZapfDingbats fonts.
   Unicode mapNameToUnicodeAll(const char *charName);
 
-  UnicodeMap *getResidentUnicodeMap(const GooString *encodingName);
-  FILE *getUnicodeMapFile(const GooString *encodingName);
+  UnicodeMap *getResidentUnicodeMap(const std::string &encodingName);
+  FILE *getUnicodeMapFile(const std::string &encodingName);
   FILE *findCMapFile(const GooString *collection, const GooString *cMapName);
   FILE *findToUnicodeFile(const GooString *name);
   GooString *findFontFile(const GooString *fontName);
-  GooString *findBase14FontFile(const GooString *base14Name, GfxFont *font);
-  GooString *findSystemFontFile(GfxFont *font, SysFontType *type,
+  GooString *findBase14FontFile(const GooString *base14Name, const GfxFont *font);
+  GooString *findSystemFontFile(const GfxFont *font, SysFontType *type,
 			      int *fontNum, GooString *substituteFontName = nullptr,
 		              const GooString *base14Name = nullptr);
   bool getPSExpandSmaller();
   bool getPSShrinkLarger();
   PSLevel getPSLevel();
-  GooString *getTextEncodingName();
-  EndOfLineKind getTextEOL();
-  bool getTextPageBreaks();
-  bool getEnableFreeType();
+  std::string getTextEncodingName() const;
   bool getOverprintPreview() { return overprintPreview; }
   bool getPrintCommands();
   bool getProfileCommands();
   bool getErrQuiet();
 
-  CharCodeToUnicode *getCIDToUnicode(GooString *collection);
-  UnicodeMap *getUnicodeMap(GooString *encodingName);
-  CMap *getCMap(const GooString *collection, GooString *cMapName, Stream *stream = nullptr);
-  UnicodeMap *getTextEncoding();
+  CharCodeToUnicode *getCIDToUnicode(const GooString *collection);
+  const UnicodeMap *getUnicodeMap(const std::string &encodingName);
+  CMap *getCMap(const GooString *collection, const GooString *cMapName, Stream *stream = nullptr);
+  const UnicodeMap *getTextEncoding();
+
+  const UnicodeMap *getUtf8Map();
 
   std::vector<GooString*> *getEncodingNames();
 
   //----- functions to set parameters
-  void addFontFile(GooString *fontName, GooString *path);
+  void addFontFile(const GooString *fontName, const GooString *path);
   void setPSExpandSmaller(bool expand);
   void setPSShrinkLarger(bool shrink);
   void setPSLevel(PSLevel level);
-  void setTextEncoding(char *encodingName);
-  bool setTextEOL(char *s);
-  void setTextPageBreaks(bool pageBreaks);
-  bool setEnableFreeType(char *s);
+  void setTextEncoding(const char *encodingName);
   void setOverprintPreview(bool overprintPreviewA);
   void setPrintCommands(bool printCommandsA);
   void setProfileCommands(bool profileCommandsA);
@@ -168,7 +158,6 @@ public:
 private:
 
   void parseNameToUnicode(const GooString *name);
-  UnicodeMap *getUnicodeMap2(GooString *encodingName);
 
   void scanEncodingDirs();
   void addCIDToUnicode(const GooString *collection, const GooString *fileName);
@@ -211,10 +200,6 @@ private:
   PSLevel psLevel;		// PostScript level to generate
   GooString *textEncoding;	// encoding (unicodeMap) to use for text
 				//   output
-  EndOfLineKind textEOL;	// type of EOL marker to use for text
-				//   output
-  bool textPageBreaks;		// insert end-of-page markers?
-  bool enableFreeType;		// FreeType enable flag
   bool overprintPreview;	// enable overprint preview
   bool printCommands;		// print the drawing commands
   bool profileCommands;	// profile the drawing commands
@@ -224,6 +209,8 @@ private:
   CharCodeToUnicodeCache *unicodeToUnicodeCache;
   UnicodeMapCache *unicodeMapCache;
   CMapCache *cMapCache;
+
+  const UnicodeMap *utf8Map;
   
   mutable std::recursive_mutex mutex;
   mutable std::recursive_mutex unicodeMapCacheMutex;
@@ -232,4 +219,22 @@ private:
   const char *popplerDataDir;
 };
 
+class GlobalParamsIniter
+{
+public:
+  GlobalParamsIniter(ErrorCallback errorCallback);
+  ~GlobalParamsIniter();
+
+  GlobalParamsIniter(const GlobalParamsIniter &) = delete;
+  GlobalParamsIniter &operator=(const GlobalParamsIniter &) = delete;
+
+  static bool setCustomDataDir(const std::string &dir);
+
+private:
+  static std::mutex mutex;
+  static int count;
+
+  static std::string customDataDir;
+};
+
 #endif
