@@ -19,6 +19,7 @@
 // Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2019 Volker Krause <vkrause@kde.org>
 // Copyright (C) 2019 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2019 Even Rouault <even.rouault@spatialys.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -45,7 +46,7 @@ class JBIG2Stream: public FilterStream {
 public:
 
   JBIG2Stream(Stream *strA, Object &&globalsStreamA, Object *globalsStreamRefA);
-  ~JBIG2Stream();
+  ~JBIG2Stream() override;
   StreamKind getKind() const override { return strJBIG2; }
   void reset() override;
   void close() override;
@@ -61,6 +62,8 @@ private:
   bool hasGetChars() override { return true; }
   int getChars(int nChars, unsigned char *buffer) override;
 
+  void freeSegments();
+
   void readSegments();
   bool readSymbolDictSeg(unsigned int segNum, unsigned int length,
 			  unsigned int *refSegs, unsigned int nRefSegs);
