@@ -51,32 +51,24 @@
 //------------------------------------------------------------------------
 LinkAction::LinkAction() = default;
 
-LinkAction::~LinkAction() {
-  for (auto entry : nextActionList) {
-    delete entry;
-  }
-}
+LinkAction::~LinkAction() = default;
 
-LinkAction *LinkAction::parseDest(const Object *obj) {
-  LinkAction *action;
-
-  action = new LinkGoTo(obj);
+std::unique_ptr<LinkAction> LinkAction::parseDest(const Object *obj) {
+  auto action = std::unique_ptr<LinkAction>(new LinkGoTo(obj));
   if (!action->isOk()) {
-    delete action;
-    return nullptr;
+    action.reset();
   }
   return action;
 }
 
-LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI)
+std::unique_ptr<LinkAction> LinkAction::parseAction(const Object *obj, const GooString *baseURI)
 {
     std::set<int> seenNextActions;
     return parseAction(obj, baseURI, &seenNextActions);
 }
 
-LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
+std::unique_ptr<LinkAction> LinkAction::parseAction(const Object *obj, const GooString *baseURI,
                                     std::set<int> *seenNextActions) {
-  LinkAction *action;
 
   if (!obj->isDict()) {
       error(errSyntaxWarning, -1, "parseAction: Bad annotation action for URI '{0:s}'",
@@ -84,61 +76,62 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
       return nullptr;
   }
 
+  std::unique_ptr<LinkAction> action;
   Object obj2 = obj->dictLookup("S");
 
   // GoTo action
   if (obj2.isName("GoTo")) {
     Object obj3 = obj->dictLookup("D");
-    action = new LinkGoTo(&obj3);
+    action = std::make_unique<LinkGoTo>(&obj3);
 
   // GoToR action
   } else if (obj2.isName("GoToR")) {
     Object obj3 = obj->dictLookup("F");
     Object obj4 = obj->dictLookup("D");
-    action = new LinkGoToR(&obj3, &obj4);
+    action = std::make_unique<LinkGoToR>(&obj3, &obj4);
 
   // Launch action
   } else if (obj2.isName("Launch")) {
-    action = new LinkLaunch(obj);
+    action = std::make_unique<LinkLaunch>(obj);
 
   // URI action
   } else if (obj2.isName("URI")) {
     Object obj3 = obj->dictLookup("URI");
-    action = new LinkURI(&obj3, baseURI);
+    action = std::make_unique<LinkURI>(&obj3, baseURI);
 
   // Named action
   } else if (obj2.isName("Named")) {
     Object obj3 = obj->dictLookup("N");
-    action = new LinkNamed(&obj3);
+    action = std::make_unique<LinkNamed>(&obj3);
 
   // Movie action
   } else if (obj2.isName("Movie")) {
-    action = new LinkMovie(obj);
+    action = std::make_unique<LinkMovie>(obj);
 
   // Rendition action
   } else if (obj2.isName("Rendition")) {
-    action = new LinkRendition(obj);
+    action = std::make_unique<LinkRendition>(obj);
 
   // Sound action
   } else if (obj2.isName("Sound")) {
-    action = new LinkSound(obj);
+    action = std::make_unique<LinkSound>(obj);
 
   // JavaScript action
   } else if (obj2.isName("JavaScript")) {
     Object obj3 = obj->dictLookup("JS");
-    action = new LinkJavaScript(&obj3);
+    action = std::make_unique<LinkJavaScript>(&obj3);
 
   // Set-OCG-State action
   } else if (obj2.isName("SetOCGState")) {
-    action = new LinkOCGState(obj);
+    action = std::make_unique<LinkOCGState>(obj);
 
   // Hide action
   } else if (obj2.isName("Hide")) {
-    action = new LinkHide(obj);
+    action = std::make_unique<LinkHide>(obj);
 
   // unknown action
   } else if (obj2.isName()) {
-    action = new LinkUnknown(obj2.getName());
+    action = std::make_unique<LinkUnknown>(obj2.getName());
 
   // action is missing or wrong type
   } else {
@@ -148,7 +141,7 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
   }
 
   if (action && !action->isOk()) {
-    delete action;
+    action.reset();
     return nullptr;
   }
 
@@ -158,7 +151,7 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
 
   // parse the next actions
   const Object nextObj = obj->dictLookup("Next");
-  std::vector<LinkAction*> actionList;
+  std::vector<std::unique_ptr<LinkAction> > actionList;
   if (nextObj.isDict()) {
 
     // Prevent circles in the tree by checking the ref against used refs in
@@ -204,7 +197,7 @@ LinkAction *LinkAction::parseAction(const Object *obj, const GooString *baseURI,
   return action;
 }
 
-const std::vector<LinkAction*>& LinkAction::nextActions() const {
+const std::vector<std::unique_ptr<LinkAction> >& LinkAction::nextActions() const {
   return nextActionList;
 }
 
@@ -432,21 +425,17 @@ LinkDest::LinkDest(const LinkDest *dest) {
 //------------------------------------------------------------------------
 
 LinkGoTo::LinkGoTo(const Object *destObj) {
-  dest = nullptr;
-  namedDest = nullptr;
-
   // named destination
   if (destObj->isName()) {
-    namedDest = new GooString(destObj->getName());
+    namedDest = std::make_unique<GooString>(destObj->getName());
   } else if (destObj->isString()) {
-    namedDest = destObj->getString()->copy();
+    namedDest = std::unique_ptr<GooString>(destObj->getString()->copy());
 
   // destination dictionary
   } else if (destObj->isArray()) {
-    dest = new LinkDest(destObj->getArray());
+    dest = std::make_unique<LinkDest>(destObj->getArray());
     if (!dest->isOk()) {
-      delete dest;
-      dest = nullptr;
+      dest.reset();
     }
 
   // error
@@ -455,40 +444,28 @@ LinkGoTo::LinkGoTo(const Object *destObj) {
   }
 }
 
-LinkGoTo::~LinkGoTo() {
-  if (dest)
-    delete dest;
-  if (namedDest)
-    delete namedDest;
-}
-
 //------------------------------------------------------------------------
 // LinkGoToR
 //------------------------------------------------------------------------
 
 LinkGoToR::LinkGoToR(Object *fileSpecObj, Object *destObj) {
-  fileName = nullptr;
-  dest = nullptr;
-  namedDest = nullptr;
-
   // get file name
   Object obj1 = getFileSpecNameForPlatform (fileSpecObj);
   if (obj1.isString()) {
-    fileName = obj1.getString()->copy();
+    fileName = std::unique_ptr<GooString>(obj1.getString()->copy());
   }
 
   // named destination
   if (destObj->isName()) {
-    namedDest = new GooString(destObj->getName());
+    namedDest = std::make_unique<GooString>(destObj->getName());
   } else if (destObj->isString()) {
-    namedDest = destObj->getString()->copy();
+    namedDest = std::unique_ptr<GooString>(destObj->getString()->copy());
 
   // destination dictionary
   } else if (destObj->isArray()) {
-    dest = new LinkDest(destObj->getArray());
+    dest = std::make_unique<LinkDest>(destObj->getArray());
     if (!dest->isOk()) {
-      delete dest;
-      dest = nullptr;
+      dest.reset();
     }
 
   // error
@@ -497,31 +474,18 @@ LinkGoToR::LinkGoToR(Object *fileSpecObj, Object *destObj) {
   }
 }
 
-LinkGoToR::~LinkGoToR() {
-  if (fileName)
-    delete fileName;
-  if (dest)
-    delete dest;
-  if (namedDest)
-    delete namedDest;
-}
-
-
 //------------------------------------------------------------------------
 // LinkLaunch
 //------------------------------------------------------------------------
 
 LinkLaunch::LinkLaunch(const Object *actionObj) {
 
-  fileName = nullptr;
-  params = nullptr;
-
   if (actionObj->isDict()) {
     Object obj1 = actionObj->dictLookup("F");
     if (!obj1.isNull()) {
       Object obj3 = getFileSpecNameForPlatform (&obj1);
       if (obj3.isString()) {
-	fileName = obj3.getString()->copy();
+	fileName = std::unique_ptr<GooString>(obj3.getString()->copy());
       }
     } else {
 #ifdef _WIN32
@@ -535,11 +499,11 @@ LinkLaunch::LinkLaunch(const Object *actionObj) {
 	Object obj2 = obj1.dictLookup("F");
 	Object obj3 = getFileSpecNameForPlatform (&obj2);
 	if (obj3.isString()) {
-	  fileName = obj3.getString()->copy();
+	  fileName = std::unique_ptr<GooString>(obj3.getString()->copy());
 	}
 	obj2 = obj1.dictLookup("P");
 	if (obj2.isString()) {
-	  params = obj2.getString()->copy();
+	  params = std::unique_ptr<GooString>(obj2.getString()->copy());
 	}
       } else {
 	error(errSyntaxWarning, -1, "Bad launch-type link action");
@@ -548,50 +512,39 @@ LinkLaunch::LinkLaunch(const Object *actionObj) {
   }
 }
 
-LinkLaunch::~LinkLaunch() {
-  if (fileName)
-    delete fileName;
-  if (params)
-    delete params;
-}
-
 //------------------------------------------------------------------------
 // LinkURI
 //------------------------------------------------------------------------
 
 LinkURI::LinkURI(const Object *uriObj, const GooString *baseURI) {
-  const GooString *uri2;
-  int n;
-  char c;
-
-  uri = nullptr;
+  hasURIFlag = false;
   if (uriObj->isString()) {
-    uri2 = uriObj->getString();
-    n = (int)strcspn(uri2->c_str(), "/:");
-    if (n < uri2->getLength() && uri2->getChar(n) == ':') {
+    hasURIFlag = true;
+    const std::string& uri2 = uriObj->getString()->toStr();
+    size_t n = strcspn(uri2.c_str(), "/:");
+    if (n < uri2.size() && uri2[n] == ':') {
       // "http:..." etc.
-      uri = uri2->copy();
-    } else if (!uri2->cmpN("www.", 4)) {
+      uri = uri2;
+    } else if (!uri2.compare(0,4,"www.")) {
       // "www.[...]" without the leading "http://"
-      uri = new GooString("http://");
-      uri->append(uri2);
+      uri = "http://" + uri2;
     } else {
       // relative URI
       if (baseURI) {
-	uri = baseURI->copy();
-	if (uri->getLength() > 0) {
-	  c = uri->getChar(uri->getLength() - 1);
+	uri = baseURI->toStr();
+	if (uri.size() > 0) {
+	  char c = uri.back();
 	  if (c != '/' && c != '?') {
-	    uri->append('/');
+	    uri += '/';
 	  }
 	}
-	if (uri2->getChar(0) == '/') {
-	  uri->append(uri2->c_str() + 1, uri2->getLength() - 1);
+	if (uri2[0] == '/') {
+	  uri.append(uri2.c_str() + 1, uri2.size() - 1);
 	} else {
-	  uri->append(uri2);
+	  uri += uri2;
 	}
       } else {
-	uri = uri2->copy();
+	uri = uri2;
       }
     }
   } else {
@@ -599,25 +552,15 @@ LinkURI::LinkURI(const Object *uriObj, const GooString *baseURI) {
   }
 }
 
-LinkURI::~LinkURI() {
-  if (uri)
-    delete uri;
-}
-
 //------------------------------------------------------------------------
 // LinkNamed
 //------------------------------------------------------------------------
 
 LinkNamed::LinkNamed(const Object *nameObj) {
-  name = nullptr;
+  hasNameFlag = false;
   if (nameObj->isName()) {
-    name = new GooString(nameObj->getName());
-  }
-}
-
-LinkNamed::~LinkNamed() {
-  if (name) {
-    delete name;
+    name = (nameObj->getName()) ? nameObj->getName() : "";
+    hasNameFlag = true;
   }
 }
 
@@ -627,7 +570,7 @@ LinkNamed::~LinkNamed() {
 
 LinkMovie::LinkMovie(const Object *obj) {
   annotRef = Ref::INVALID();
-  annotTitle = nullptr;
+  hasAnnotTitleFlag = false;
 
   const Object &annotationObj = obj->dictLookupNF("Annotation");
   if (annotationObj.isRef()) {
@@ -636,10 +579,11 @@ LinkMovie::LinkMovie(const Object *obj) {
 
   Object tmp = obj->dictLookup("T");
   if (tmp.isString()) {
-    annotTitle = tmp.getString()->copy();
+    annotTitle = tmp.getString()->toStr();
+    hasAnnotTitleFlag = true;
   }
 
-  if ((annotTitle == nullptr) && (annotRef == Ref::INVALID())) {
+  if ((!hasAnnotTitleFlag) && (annotRef == Ref::INVALID())) {
     error(errSyntaxError, -1,
 	  "Movie action is missing both the Annot and T keys");
   }
@@ -663,12 +607,6 @@ LinkMovie::LinkMovie(const Object *obj) {
   }
 }
 
-LinkMovie::~LinkMovie() {
-  if (annotTitle) {
-    delete annotTitle;
-  }
-}
-
 //------------------------------------------------------------------------
 // LinkSound
 //------------------------------------------------------------------------
@@ -707,10 +645,6 @@ LinkSound::LinkSound(const Object *soundObj) {
   }
 }
 
-LinkSound::~LinkSound() {
-  delete sound;
-}
-
 //------------------------------------------------------------------------
 // LinkRendition
 //------------------------------------------------------------------------
@@ -718,7 +652,6 @@ LinkSound::~LinkSound() {
 LinkRendition::LinkRendition(const Object *obj) {
   operation = NoRendition;
   media = nullptr;
-  js = nullptr;
   int operationCode = -1;
 
   screenRef = Ref::INVALID();
@@ -727,11 +660,10 @@ LinkRendition::LinkRendition(const Object *obj) {
     Object tmp = obj->dictLookup("JS");
     if (!tmp.isNull()) {
       if (tmp.isString()) {
-        js = new GooString(tmp.getString());
+        js = tmp.getString()->toStr();
       } else if (tmp.isStream()) {
         Stream *stream = tmp.getStream();
-	js = new GooString();
-	stream->fillGooString(js);
+	stream->fillString(js);
       } else {
         error(errSyntaxWarning, -1, "Invalid Rendition Action: JS not string or stream");
       }
@@ -740,7 +672,7 @@ LinkRendition::LinkRendition(const Object *obj) {
     tmp = obj->dictLookup("OP");
     if (tmp.isInt()) {
       operationCode = tmp.getInt();
-      if (!js && (operationCode < 0 || operationCode > 4)) {
+      if (js.empty() && (operationCode < 0 || operationCode > 4)) {
         error(errSyntaxWarning, -1, "Invalid Rendition Action: unrecognized operation valued: {0:d}", operationCode);
       } else {
         // retrieve rendition object
@@ -777,14 +709,13 @@ LinkRendition::LinkRendition(const Object *obj) {
           operation = PlayRendition;
           break;
       }
-    } else if (!js) {
+    } else if (js=="") {
       error(errSyntaxWarning, -1, "Invalid Rendition action: no OP or JS field defined");
     }
   }
 }
 
 LinkRendition::~LinkRendition() {
-  delete js;
   delete media;
 }
 
@@ -794,21 +725,16 @@ LinkRendition::~LinkRendition() {
 //------------------------------------------------------------------------
 
 LinkJavaScript::LinkJavaScript(Object *jsObj) {
-  js = nullptr;
+  isValid = false;
 
   if (jsObj->isString()) {
-    js = new GooString(jsObj->getString());
+    js = jsObj->getString()->toStr();
+    isValid = true;
   }
   else if (jsObj->isStream()) {
     Stream *stream = jsObj->getStream();
-    js = new GooString();
-    stream->fillGooString(js);
-  }
-}
-
-LinkJavaScript::~LinkJavaScript() {
-  if (js) {
-    delete js;
+    stream->fillString(js);
+    isValid = true;
   }
 }
 
@@ -872,13 +798,14 @@ LinkOCGState::LinkOCGState(const Object *obj)
 //------------------------------------------------------------------------
 
 LinkHide::LinkHide(const Object *hideObj) {
-  targetName = nullptr;
+  hasTargetNameFlag = false;
   show = false; // Default
 
   if (hideObj->isDict()) {
       const Object targetObj = hideObj->dictLookup("T");
       if (targetObj.isString()) {
-	targetName = targetObj.getString()->copy();
+	targetName = targetObj.getString()->toStr();
+        hasTargetNameFlag = true;
       }
       const Object shouldHide = hideObj->dictLookup("H");
       if (shouldHide.isBool()) {
@@ -887,20 +814,12 @@ LinkHide::LinkHide(const Object *hideObj) {
   }
 }
 
-LinkHide::~LinkHide() {
-  delete targetName;
-}
-
 //------------------------------------------------------------------------
 // LinkUnknown
 //------------------------------------------------------------------------
 
 LinkUnknown::LinkUnknown(const char *actionA) {
-  action = new GooString(actionA);
-}
-
-LinkUnknown::~LinkUnknown() {
-  delete action;
+  action = std::string(actionA ? actionA : "");
 }
 
 //------------------------------------------------------------------------
