@@ -24,7 +24,7 @@
 
 #include <config.h>
 
-#include <stddef.h>
+#include <cstddef>
 #include "Object.h"
 #include "Array.h"
 #include "Dict.h"
