@@ -8,6 +8,7 @@
 // Copyright 2008, 2010, 2011, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright 2008 Mark Kaplan <mkaplan@finjan.com>
 // Copyright 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // Released under the GPL (version 2, or later, at your option)
 //
@@ -17,7 +18,6 @@
 
 #include "goo/gmem.h"
 #include "goo/GooString.h"
-#include "goo/GooList.h"
 #include "Error.h"
 #include "OptionalContent.h"
 
@@ -126,17 +126,6 @@ OptionalContentGroup* OCGs::findOcgByRef( const Ref ref )
   return ocg != optionalContentGroups.end() ? ocg->second.get() : nullptr;
 }
 
-OCDisplayNode *OCGs::getDisplayRoot()
-{
-  if (display)
-    return display.get();
-
-  if (order.isArray())
-    display.reset(OCDisplayNode::parse(&order, this, m_xref));
-
-  return display.get();
-}
-
 bool OCGs::optContentIsVisible( const Object *dictRef )
 {
   Dict *dict;
@@ -364,110 +353,3 @@ OptionalContentGroup::~OptionalContentGroup()
 {
   delete m_name;
 }
-
-//------------------------------------------------------------------------
-
-OCDisplayNode *OCDisplayNode::parse(const Object *obj, OCGs *oc,
-				    XRef *xref, int recursion) {
-  OptionalContentGroup *ocgA;
-  OCDisplayNode *node, *child;
-  int i;
-
-  if (recursion > displayNodeRecursionLimit) {
-    error(errSyntaxError, -1, "Loop detected in optional content order");
-    return nullptr;
-  }
-  if (obj->isRef()) {
-    if ((ocgA = oc->findOcgByRef(obj->getRef()))) {
-      return new OCDisplayNode(ocgA);
-    }
-  }
-  Object obj2 = obj->fetch(xref);
-  if (!obj2.isArray()) {
-    return nullptr;
-  }
-  i = 0;
-  if (obj2.arrayGetLength() >= 1) {
-    Object obj3 = obj2.arrayGet(0);
-    if (obj3.isString()) {
-      node = new OCDisplayNode(obj3.getString());
-      i = 1;
-    } else {
-      node = new OCDisplayNode();
-    }
-  } else {
-    node = new OCDisplayNode();
-  }
-  for (; i < obj2.arrayGetLength(); ++i) {
-    const Object &obj3 = obj2.arrayGetNF(i);
-    if ((child = OCDisplayNode::parse(&obj3, oc, xref, recursion + 1))) {
-      if (!child->ocg && !child->name && node->getNumChildren() > 0) {
-	node->getChild(node->getNumChildren() - 1)->addChildren(child->takeChildren());
-	delete child;
-      } else {
-	node->addChild(child);
-      }
-    }
-  }
-  return node;
-}
-
-OCDisplayNode::OCDisplayNode() {
-  name = nullptr;
-  ocg = nullptr;
-  children = nullptr;
-}
-
-OCDisplayNode::OCDisplayNode(const GooString *nameA) {
-  name = new GooString(nameA);
-  ocg = nullptr;
-  children = nullptr;
-}
-
-OCDisplayNode::OCDisplayNode(OptionalContentGroup *ocgA) {
-  name = (ocgA->getName()) ? ocgA->getName()->copy() : nullptr;
-  ocg = ocgA;
-  children = nullptr;
-}
-
-void OCDisplayNode::addChild(OCDisplayNode *child) {
-  if (!children) {
-    children = new GooList();
-  }
-  children->push_back(child);
-}
-
-void OCDisplayNode::addChildren(GooList *childrenA) {
-  if (!children) {
-    children = new GooList();
-  }
-  children->reserve(children->size() + childrenA->size());
-  children->insert(children->end(), childrenA->begin(), childrenA->end());
-  delete childrenA;
-}
-
-GooList *OCDisplayNode::takeChildren() {
-  GooList *childrenA;
-
-  childrenA = children;
-  children = nullptr;
-  return childrenA;
-}
-
-OCDisplayNode::~OCDisplayNode() {
-  gfree(name);
-  if (children) {
-    deleteGooList<OCDisplayNode>(children);
-  }
-}
-
-int OCDisplayNode::getNumChildren() const {
-  if (!children) {
-    return 0;
-  }
-  return children->getLength();
-}
-
-OCDisplayNode *OCDisplayNode::getChild(int idx) const {
-  return (OCDisplayNode *)children->get(idx);
-}
