@@ -4,8 +4,9 @@
 //
 // Copyright 2007 Brad Hards <bradh@kde.org>
 // Copyright 2008 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright 2013, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright 2013, 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // Released under the GPL (version 2, or later, at your option)
 //
@@ -20,11 +21,9 @@
 #include <memory>
 
 class GooString;
-class GooList;
 class XRef;
 
 class OptionalContentGroup;
-class OCDisplayNode;
 
 //------------------------------------------------------------------------
 
@@ -42,23 +41,19 @@ public:
   bool hasOCGs() const;
   const std::unordered_map< Ref, std::unique_ptr< OptionalContentGroup > > &getOCGs() const { return optionalContentGroups; }
 
-  OptionalContentGroup* findOcgByRef( const Ref &ref);
-
-  // Get the root node of the optional content group display tree
-  // (which does not necessarily include all of the OCGs).
-  OCDisplayNode *getDisplayRoot();
+  OptionalContentGroup* findOcgByRef( const Ref ref);
 
   Array* getOrderArray() 
     { return (order.isArray() && order.arrayGetLength() > 0) ? order.getArray() : nullptr; }
   Array* getRBGroupsArray() 
     { return (rbgroups.isArray() && rbgroups.arrayGetLength()) ? rbgroups.getArray() : nullptr; }
 
-  bool optContentIsVisible( Object *dictRef );
+  bool optContentIsVisible( const Object *dictRef );
 
 private:
   bool ok;
 
-  bool evalOCVisibilityExpr(Object *expr, int recursion);
+  bool evalOCVisibilityExpr(const Object *expr, int recursion);
   bool allOn( Array *ocgArray );
   bool allOff( Array *ocgArray );
   bool anyOn( Array *ocgArray );
@@ -69,7 +64,6 @@ private:
   Object order;
   Object rbgroups;
   XRef *m_xref;
-  std::unique_ptr< OCDisplayNode > display; // root node of display tree
 };
 
 //------------------------------------------------------------------------
@@ -99,11 +93,11 @@ public:
   Ref getRef() const;
   void setRef(const Ref ref);
 
-  State getState() { return m_state; };
+  State getState() const { return m_state; };
   void setState(State state) { m_state = state; };
 
-  UsageState getViewState() { return viewState; }
-  UsageState getPrintState() { return printState; }
+  UsageState getViewState() const { return viewState; }
+  UsageState getPrintState() const { return printState; }
 
 private:
   GooString *m_name;
@@ -115,33 +109,4 @@ private:
 
 //------------------------------------------------------------------------
 
-class OCDisplayNode {
-public:
-
-  static OCDisplayNode *parse(Object *obj, OCGs *oc, XRef *xref, int recursion = 0);
-  OCDisplayNode();
-  ~OCDisplayNode();
-
-  OCDisplayNode(const OCDisplayNode &) = delete;
-  OCDisplayNode& operator=(const OCDisplayNode &) = delete;
-
-  const GooString *getName() const { return name; }
-  const OptionalContentGroup *getOCG() const { return ocg; }
-  int getNumChildren() const;
-  OCDisplayNode *getChild(int idx) const;
-
-private:
-
-  OCDisplayNode(const GooString *nameA);
-  OCDisplayNode(OptionalContentGroup *ocgA);
-  void addChild(OCDisplayNode *child);
-  void addChildren(GooList *childrenA);
-  GooList *takeChildren();
-
-  GooString *name;		// display name (may be nullptr)
-  OptionalContentGroup *ocg;	// nullptr for display labels
-  GooList *children;		// nullptr if there are no children
-				//   [OCDisplayNode]
-};
-
 #endif
