@@ -52,15 +52,15 @@
 #include <config.h>
 #include <poppler-config.h>
 
-#include <ctype.h>
-#include <locale.h>
-#include <stdio.h>
-#include <errno.h>
-#include <limits.h>
-#include <stdlib.h>
-#include <stddef.h>
-#include <string.h>
-#include <time.h>
+#include <cctype>
+#include <clocale>
+#include <cstdio>
+#include <cerrno>
+#include <climits>
+#include <cstdlib>
+#include <cstddef>
+#include <cstring>
+#include <ctime>
 #include <regex>
 #include <sys/stat.h>
 #include "goo/glibc.h"
@@ -473,7 +473,7 @@ bool PDFDoc::checkEncryption(const GooString *ownerPassword, const GooString *us
 static PDFSubtypePart pdfPartFromString(PDFSubtype subtype, GooString *pdfSubtypeVersion) {
   const std::regex regex("PDF/(?:A|X|VT|E|UA)-([[:digit:]])(?:[[:alpha:]]{1,2})?:?([[:digit:]]{4})?");
   std::smatch match;
-  std::string pdfsubver = pdfSubtypeVersion->toStr();
+  const std::string &pdfsubver = pdfSubtypeVersion->toStr();
   PDFSubtypePart subtypePart = subtypePartNone;
 
   if (std::regex_search(pdfsubver, match, regex)) {
@@ -533,7 +533,7 @@ static PDFSubtypePart pdfPartFromString(PDFSubtype subtype, GooString *pdfSubtyp
 static PDFSubtypeConformance pdfConformanceFromString(GooString *pdfSubtypeVersion) {
   const std::regex regex("PDF/(?:A|X|VT|E|UA)-[[:digit:]]([[:alpha:]]+)");
   std::smatch match;
-  const std::string pdfsubver = pdfSubtypeVersion->toStr();
+  const std::string &pdfsubver = pdfSubtypeVersion->toStr();
   PDFSubtypeConformance pdfConf = subtypeConfNone;
 
   // match contains the PDF conformance (A, B, G, N, P, PG or U)
