@@ -13,10 +13,11 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2006, 2010, 2013, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2010, 2013, 2017, 2018, 2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
+// Copyright (C) 2019 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -36,7 +37,8 @@ class Parser {
 public:
 
   // Constructor.
-  Parser(XRef *xrefA, Lexer *lexerA, bool allowStreamsA);
+  Parser(XRef *xrefA, Stream *streamA, bool allowStreamsA);
+  Parser(XRef *xrefA, Object *objectA, bool allowStreamsA);
 
   // Destructor.
   ~Parser();
@@ -48,7 +50,7 @@ public:
   // true, do not parse compound objects (arrays, dictionaries, or
   // streams).
   Object getObj(bool simpleOnly = false,
-     unsigned char *fileKey = nullptr,
+		 const unsigned char *fileKey = nullptr,
 		 CryptAlgorithm encAlgorithm = cryptRC4, int keyLength = 0,
 		 int objNum = 0, int objGen = 0, int recursion = 0,
 		 bool strict = false);
@@ -57,20 +59,19 @@ public:
   template<typename T> Object getObj(T) = delete;
 
   // Get stream.
-  Stream *getStream() { return lexer->getStream(); }
+  Stream *getStream() { return lexer.getStream(); }
 
   // Get current position in file.
-  Goffset getPos() { return lexer->getPos(); }
+  Goffset getPos() { return lexer.getPos(); }
 
 private:
 
-  XRef *xref;			// the xref table for this PDF file
-  Lexer *lexer;			// input stream
+  Lexer lexer;			// input stream
   bool allowStreams;		// parse stream objects?
   Object buf1, buf2;		// next two tokens
   int inlineImg;		// set when inline image data is encountered
 
-  Stream *makeStream(Object &&dict, unsigned char *fileKey,
+  Stream *makeStream(Object &&dict, const unsigned char *fileKey,
 		     CryptAlgorithm encAlgorithm, int keyLength,
 		     int objNum, int objGen, int recursion,
 		     bool strict);
