@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2010, 2011, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2010, 2011, 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2011, 2014 William Bader <williambader@hotmail.com>
 // Copyright (C) 2011, 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2011 Adrian Johnson <ajohnson@redneon.com>
@@ -26,7 +26,7 @@
 
 #include <config.h>
 
-#include <math.h>
+#include <cmath>
 #include "GlobalParams.h"
 #include "Gfx.h"
 #include "GfxFont.h"
@@ -185,7 +185,7 @@ void PreScanOutputDev::endStringOp(GfxState * /*state*/) {
 
 bool PreScanOutputDev::beginType3Char(GfxState * /*state*/, double /*x*/, double /*y*/,
 				       double /*dx*/, double /*dy*/,
-				       CharCode /*code*/, Unicode * /*u*/, int /*uLen*/) {
+				       CharCode /*code*/, const Unicode * /*u*/, int /*uLen*/) {
   // return false so all Type 3 chars get rendered (no caching)
   return false;
 }
@@ -218,7 +218,7 @@ void PreScanOutputDev::drawImageMask(GfxState *state, Object * /*ref*/, Stream *
 void PreScanOutputDev::drawImage(GfxState *state, Object * /*ref*/, Stream *str,
 				 int width, int height,
 				 GfxImageColorMap *colorMap,
-				 bool /*interpolate*/, int * /*maskColors*/, bool inlineImg) {
+				 bool /*interpolate*/, const int * /*maskColors*/, bool inlineImg) {
   GfxColorSpace *colorSpace;
   int i, j;
 
