@@ -9,13 +9,15 @@
 // Copyright 2015, 2017, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright 2017 Hans-Ulrich Jüttner <huj@froreich-bioscientia.de>
 // Copyright 2018 Chinmoy Ranjan Pradhan <chinmoyrp65@protonmail.com>
+// Copyright 2018 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 //========================================================================
 
 #ifndef SIGNATUREINFO_H
 #define SIGNATUREINFO_H
 
-#include <time.h>
+#include <memory>
+#include <ctime>
 
 enum SignatureValidationStatus
 {
@@ -39,12 +41,17 @@ enum CertificateValidationStatus
   CERTIFICATE_NOT_VERIFIED
 };
 
+class X509CertificateInfo;
+
 class SignatureInfo {
 public:
   SignatureInfo();
   SignatureInfo(SignatureValidationStatus, CertificateValidationStatus);
   ~SignatureInfo();
 
+  SignatureInfo(const SignatureInfo &) = delete;
+  SignatureInfo& operator=(const SignatureInfo &) = delete;
+
   /* GETTERS */
   SignatureValidationStatus getSignatureValStatus();
   CertificateValidationStatus getCertificateValStatus();
@@ -55,6 +62,7 @@ public:
   int getHashAlgorithm(); // Returns a NSS3 HASH_HashType or -1 if compiled without NSS3
   time_t getSigningTime();
   bool isSubfilterSupported() { return sig_subfilter_supported; }
+  const X509CertificateInfo *getCertificateInfo() const;
 
   /* SETTERS */
   void setSignatureValStatus(enum SignatureValidationStatus );
@@ -66,13 +74,12 @@ public:
   void setHashAlgorithm(int);
   void setSigningTime(time_t);
   void setSubFilterSupport(bool isSupported) { sig_subfilter_supported = isSupported; }
+  void setCertificateInfo(std::unique_ptr<X509CertificateInfo>);
 
 private:
-  SignatureInfo(const SignatureInfo &);
-  SignatureInfo& operator=(const SignatureInfo &);
-
   SignatureValidationStatus sig_status;
   CertificateValidationStatus cert_status;
+  std::unique_ptr<X509CertificateInfo> cert_info;
   char *signer_name;
   char *subject_dn;
   char *location;
