@@ -17,6 +17,7 @@
 // Copyright (C) 2012 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2016 Khaled Hosny <khaledhosny@eglug.org>
 // Copyright (C) 2019 Adriaan de Groot <groot@kde.org>
+// Copyright (C) 2019 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -26,6 +27,8 @@
 #ifndef UNICODETYPETABLE_H
 #define UNICODETYPETABLE_H
 
+#include "CharTypes.h"
+
 extern bool unicodeTypeL(Unicode c);
 
 extern bool unicodeTypeR(Unicode c);
@@ -39,10 +42,10 @@ extern bool unicodeIsAlphabeticPresentationForm(Unicode c);
 extern Unicode unicodeToUpper(Unicode c);
 
 extern Unicode *unicodeNormalizeNFKC(const Unicode *in, int len,
-				     int *out_len, int **offsets);
+				     int *out_len, int **indices);
 
 extern Unicode *unicodeNormalizeNFKC(const Unicode *in, int len,
-				     int *out_len, int **offsets,
+				     int *out_len, int **indices,
 				     bool reverseRTL);
 
 #endif
