@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2006, 2008, 2010-2013, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2008, 2010-2013, 2017-2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2007-2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2010 Ilya Gorenbein <igorenbein@finjan.com>
@@ -24,6 +24,7 @@
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2018 Marek Kasik <mkasik@redhat.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -34,7 +35,6 @@
 #define XREF_H
 
 #include "poppler-config.h"
-#include "goo/gtypes.h"
 #include "Object.h"
 #include "Stream.h"
 #include "PopplerCache.h"
@@ -65,6 +65,7 @@ struct XRefEntry {
   enum Flag {
     // Regular flags
     Updated,     // Entry was modified
+    Parsing,     // Entry is currently being parsed
 
     // Special flags -- available only after xref->scanSpecialFlags() is run
     Unencrypted, // Entry is stored in unencrypted form (meaningless in unencrypted documents)
@@ -116,17 +117,20 @@ public:
 
   // Set the encryption parameters.
   void setEncryption(int permFlagsA, bool ownerPasswordOkA,
-		     const Guchar *fileKeyA, int keyLengthA,
+		     const unsigned char *fileKeyA, int keyLengthA,
 		     int encVersionA, int encRevisionA,
 		     CryptAlgorithm encAlgorithmA);
   // Mark Encrypt entry as Unencrypted
   void markUnencrypted();
 
-  void getEncryptionParameters(Guchar **fileKeyA, CryptAlgorithm *encAlgorithmA, int *keyLengthA);
+  void getEncryptionParameters(unsigned char **fileKeyA, CryptAlgorithm *encAlgorithmA, int *keyLengthA);
 
   // Is the file encrypted?
   bool isEncrypted() const { return encrypted; }
 
+  // Is the given Ref encrypted?
+  bool isRefEncrypted(Ref r);
+
   // Check various permissions.
   bool okToPrint(bool ignoreOwnerPW = false) const;
   bool okToPrintHighRes(bool ignoreOwnerPW = false) const;
@@ -142,6 +146,7 @@ public:
   Object getCatalog();
 
   // Fetch an indirect reference.
+  Object fetch(const Ref ref, int recursion = 0);
   Object fetch(int num, int gen, int recursion = 0);
 
   // Return the document's Info dictionary (if any).
@@ -161,6 +166,7 @@ public:
   // Return the catalog object reference.
   int getRootNum() const { return rootNum; }
   int getRootGen() const { return rootGen; }
+  Ref getRoot() const { return { rootNum, rootGen }; }
 
   // Get end position for a stream in a damaged file.
   // Returns false if unknown or file is not damaged.
@@ -191,6 +197,7 @@ public:
   Ref addIndirectObject (const Object* o);
   void removeIndirectObject(Ref r);
   void add(int num, int gen,  Goffset offs, bool used);
+  void add(Ref ref, Goffset offs, bool used);
 
   // Output XRef table to stream
   void writeTableToFile(OutStream* outStr, bool writeAllEntries);
@@ -225,7 +232,7 @@ private:
   CryptAlgorithm encAlgorithm;	// encryption algorithm
   int keyLength;		// length of key, in bytes
   int permFlags;		// permission bits
-  Guchar fileKey[32];		// file decryption key
+  unsigned char fileKey[32];		// file decryption key
   bool ownerPasswordOk;	// true if owner password is correct
   Goffset prevXRefOffset;		// position of prev XRef section (= next to read)
   Goffset mainXRefEntriesOffset; // offset of entries in main XRef table
@@ -239,7 +246,7 @@ private:
   int resize(int newSize);
   bool readXRef(Goffset *pos, std::vector<Goffset> *followedXRefStm, std::vector<int> *xrefStreamObjsNum);
   bool readXRefTable(Parser *parser, Goffset *pos, std::vector<Goffset> *followedXRefStm, std::vector<int> *xrefStreamObjsNum);
-  bool readXRefStreamSection(Stream *xrefStr, int *w, int first, int n);
+  bool readXRefStreamSection(Stream *xrefStr, const int *w, int first, int n);
   bool readXRefStream(Stream *xrefStr, Goffset *pos);
   bool constructXRef(bool *wasReconstructed, bool needCatalogDict = false);
   bool parseEntry(Goffset offset, XRefEntry *entry);
