@@ -35,8 +35,8 @@
 
 #include <config.h>
 
-#include <string.h>
-#include <math.h>
+#include <cstring>
+#include <cmath>
 
 #include <array>
 
@@ -181,10 +181,6 @@ void ArthurOutputDev::startDoc(PDFDoc* doc) {
   xref = doc->getXRef();
   m_doc = doc;
 
-  if (!globalParams->getEnableFreeType()) {
-    qCritical() << "Arthur backend will not render text without FreeType, but it is disabled!";
-  }
-
   for (auto& codeToGID : m_codeToGIDCache) {
     gfree(const_cast<int*>(codeToGID.second));
   }
