@@ -1,5 +1,7 @@
 /* poppler-link-private.h: qt interface to poppler
  * Copyright (C) 2016, 2018, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2018 Intevation GmbH <intevation@intevation.de>
+ * Copyright (C) 2020 Oliver Sander <oliver.sander@tu-dresden.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,10 +21,16 @@
 #ifndef _POPPLER_LINK_PRIVATE_H_
 #define _POPPLER_LINK_PRIVATE_H_
 
+#include <vector>
+
+#include "Link.h"
+
 class LinkOCGState;
 
 namespace Poppler {
 
+class Link;
+
 class LinkPrivate
 {
 public:
@@ -33,12 +41,19 @@ public:
 
     virtual ~LinkPrivate()
     {
+        qDeleteAll(nextLinks);
+    }
+
+    static LinkPrivate *get( Link *link )
+    {
+        return link->d_ptr;
     }
 
     LinkPrivate(const LinkPrivate &) = delete;
     LinkPrivate& operator=(const LinkPrivate &) = delete;
 
     QRectF linkArea;
+    QVector <Link *> nextLinks;
 };
 
 
@@ -46,13 +61,33 @@ public:
 class LinkOCGStatePrivate : public LinkPrivate
 {
 public:
-    LinkOCGStatePrivate( const QRectF &area, ::LinkOCGState *plocg )
+    LinkOCGStatePrivate( const QRectF &area,
+                         const std::vector<::LinkOCGState::StateList>& sList,
+                         bool pRB )
         : LinkPrivate( area )
-        , popplerLinkOCGState( plocg )
+        , stateList( sList )
+        , preserveRB( pRB )
     {
     }
 
-    ::LinkOCGState *popplerLinkOCGState;
+    std::vector<::LinkOCGState::StateList> stateList;
+    bool preserveRB;
+};
+
+
+
+class LinkHidePrivate : public LinkPrivate
+{
+public:
+    LinkHidePrivate( const QRectF &area, const QString &tName, bool show )
+        : LinkPrivate( area )
+        , targetName( tName )
+        , isShow( show )
+    {
+    }
+
+    QString targetName;
+    bool isShow;
 };
 
 }
