@@ -23,6 +23,7 @@
  * Copyright (C) 2018 Intevation GmbH <intevation@intevation.de>
  * Copyright (C) 2018, Tobias Deiminger <haxtibal@posteo.de>
  * Copyright (C) 2018 Nelson Benítez León <nbenitezl@gmail.com>
+ * Copyright (C) 2020 Oliver Sander <oliver.sander@tu-dresden.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -236,30 +237,30 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
 
     case actionNamed:
     {
-      const char * name = ((LinkNamed *)a)->getName()->c_str();
-      if ( !strcmp( name, "NextPage" ) )
+      const std::string& name = ((LinkNamed *)a)->getName();
+      if ( name == "NextPage" )
         popplerLink = new LinkAction( linkArea, LinkAction::PageNext );
-      else if ( !strcmp( name, "PrevPage" ) )
+      else if ( name == "PrevPage" )
         popplerLink = new LinkAction( linkArea, LinkAction::PagePrev );
-      else if ( !strcmp( name, "FirstPage" ) )
+      else if ( name == "FirstPage" )
         popplerLink = new LinkAction( linkArea, LinkAction::PageFirst );
-      else if ( !strcmp( name, "LastPage" ) )
+      else if ( name == "LastPage" )
         popplerLink = new LinkAction( linkArea, LinkAction::PageLast );
-      else if ( !strcmp( name, "GoBack" ) )
+      else if ( name == "GoBack" )
         popplerLink = new LinkAction( linkArea, LinkAction::HistoryBack );
-      else if ( !strcmp( name, "GoForward" ) )
+      else if ( name == "GoForward" )
         popplerLink = new LinkAction( linkArea, LinkAction::HistoryForward );
-      else if ( !strcmp( name, "Quit" ) )
+      else if ( name == "Quit" )
         popplerLink = new LinkAction( linkArea, LinkAction::Quit );
-      else if ( !strcmp( name, "GoToPage" ) )
+      else if ( name == "GoToPage" )
         popplerLink = new LinkAction( linkArea, LinkAction::GoToPage );
-      else if ( !strcmp( name, "Find" ) )
+      else if ( name == "Find" )
         popplerLink = new LinkAction( linkArea, LinkAction::Find );
-      else if ( !strcmp( name, "FullScreen" ) )
+      else if ( name == "FullScreen" )
         popplerLink = new LinkAction( linkArea, LinkAction::Presentation );
-      else if ( !strcmp( name, "Print" ) )
+      else if ( name == "Print" )
         popplerLink = new LinkAction( linkArea, LinkAction::Print );
-      else if ( !strcmp( name, "Close" ) )
+      else if ( name == "Close" )
       {
         // acroread closes the document always, doesnt care whether 
         // its presentation mode or not
@@ -275,7 +276,7 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
 
     case actionURI:
     {
-      popplerLink = new LinkBrowse( linkArea, ((LinkURI *)a)->getURI()->c_str() );
+      popplerLink = new LinkBrowse( linkArea, ((LinkURI *)a)->getURI().c_str() );
     }
     break;
 
@@ -289,7 +290,7 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
     case actionJavaScript:
     {
       ::LinkJavaScript *ljs = (::LinkJavaScript *)a;
-      popplerLink = new LinkJavaScript( linkArea, UnicodeParsedString(ljs->getScript()) );
+      popplerLink = new LinkJavaScript( linkArea, UnicodeParsedString( ljs->getScript() ) );
     }
     break;
 
@@ -361,9 +362,9 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
   if ( popplerLink )
   {
     QVector<Link *> links;
-    for ( ::LinkAction *nextAction : a->nextActions() )
+    for ( const std::unique_ptr<::LinkAction>& nextAction : a->nextActions() )
     {
-      links << convertLinkActionToLink( nextAction, parentDoc, linkArea );
+      links << convertLinkActionToLink( nextAction.get(), parentDoc, linkArea );
     }
     LinkPrivate::get(popplerLink)->nextLinks = links;
   }
@@ -835,12 +836,11 @@ Link *Page::action( PageAction act ) const
     Dict *dict = o.getDict();
     const char *key = act == Page::Opening ? "O" : "C";
     Object o2 = dict->lookup((char*)key);
-    ::LinkAction *lact = ::LinkAction::parseAction(&o2, m_page->parentDoc->doc->getCatalog()->getBaseURI() );
+    std::unique_ptr<::LinkAction> lact = ::LinkAction::parseAction(&o2, m_page->parentDoc->doc->getCatalog()->getBaseURI() );
     Link *popplerLink = nullptr;
     if (lact != nullptr)
     {
-      popplerLink = m_page->convertLinkActionToLink(lact, QRectF());
-      delete lact;
+      popplerLink = m_page->convertLinkActionToLink(lact.get(), QRectF());
     }
     return popplerLink;
   }
