@@ -1,6 +1,6 @@
 /* poppler-sound.cc: qt interface to poppler
  * Copyright (C) 2006-2007, Pino Toscano <pino@kde.org>
- * Copyright (C) 2008, 2018, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2008, 2018, 2020, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,8 +78,7 @@ QString SoundObject::url() const
 	if ( m_soundData->m_type != SoundObject::External )
 		return QString();
 
-	const GooString * goo = m_soundData->m_soundObj->getFileName();
-	return goo ? QString( goo->getCString() ) : QString();
+	return QString( m_soundData->m_soundObj->getFileName().c_str() );
 }
 
 QByteArray SoundObject::data() const
