@@ -21,8 +21,8 @@
 
 #include <config.h>
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <algorithm>
 #include "goo/gmem.h"
 #include "goo/grandom.h"
