@@ -13,6 +13,7 @@
 //
 // Copyright (C) 2009, 2011, 2012, 2015 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2019 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -21,7 +22,7 @@
 
 #include <config.h>
 
-#include <string.h>
+#include <cstring>
 #include "goo/gmem.h"
 #include "SplashPattern.h"
 #include "SplashScreen.h"
@@ -35,10 +36,7 @@
 
 // number of components in each color mode
 int splashColorModeNComps[] = {
-  1, 1, 3, 3, 4
-#ifdef SPLASH_CMYK
-  , 4, 4 + SPOT_NCOMPS
-#endif
+  1, 1, 3, 3, 4, 4, 4 + SPOT_NCOMPS
 };
 
 SplashState::SplashState(int width, int height, bool vectorAntialias,
@@ -80,14 +78,13 @@ SplashState::SplashState(int width, int height, bool vectorAntialias,
     rgbTransferG[i] = (unsigned char)i;
     rgbTransferB[i] = (unsigned char)i;
     grayTransfer[i] = (unsigned char)i;
-#ifdef SPLASH_CMYK
     cmykTransferC[i] = (unsigned char)i;
     cmykTransferM[i] = (unsigned char)i;
     cmykTransferY[i] = (unsigned char)i;
     cmykTransferK[i] = (unsigned char)i;
-    for (int cp = 0; cp < SPOT_NCOMPS+4; cp++)
-      deviceNTransfer[cp][i] = (unsigned char)i;
-#endif
+    for (auto &cp : deviceNTransfer) {
+      cp[i] = (unsigned char)i;
+    }
   }
   overprintMask = 0xffffffff;
   overprintAdditive = false;
@@ -133,14 +130,13 @@ SplashState::SplashState(int width, int height, bool vectorAntialias,
     rgbTransferG[i] = (unsigned char)i;
     rgbTransferB[i] = (unsigned char)i;
     grayTransfer[i] = (unsigned char)i;
-#ifdef SPLASH_CMYK
     cmykTransferC[i] = (unsigned char)i;
     cmykTransferM[i] = (unsigned char)i;
     cmykTransferY[i] = (unsigned char)i;
     cmykTransferK[i] = (unsigned char)i;
-    for (int cp = 0; cp < SPOT_NCOMPS+4; cp++)
-      deviceNTransfer[cp][i] = (unsigned char)i;
-#endif
+    for (auto &cp : deviceNTransfer) {
+      cp[i] = (unsigned char)i;
+    }
   }
   overprintMask = 0xffffffff;
   overprintAdditive = false;
@@ -184,14 +180,12 @@ SplashState::SplashState(SplashState *state) {
   memcpy(rgbTransferG, state->rgbTransferG, 256);
   memcpy(rgbTransferB, state->rgbTransferB, 256);
   memcpy(grayTransfer, state->grayTransfer, 256);
-#ifdef SPLASH_CMYK
   memcpy(cmykTransferC, state->cmykTransferC, 256);
   memcpy(cmykTransferM, state->cmykTransferM, 256);
   memcpy(cmykTransferY, state->cmykTransferY, 256);
   memcpy(cmykTransferK, state->cmykTransferK, 256);
   for (int cp = 0; cp < SPOT_NCOMPS+4; cp++)
     memcpy(deviceNTransfer[cp], state->deviceNTransfer[cp], 256);
-#endif
   overprintMask = state->overprintMask;
   overprintAdditive = state->overprintAdditive;
   next = nullptr;
@@ -246,22 +240,18 @@ void SplashState::setSoftMask(SplashBitmap *softMaskA) {
 
 void SplashState::setTransfer(unsigned char *red, unsigned char *green, unsigned char *blue,
 			      unsigned char *gray) {
-#ifdef SPLASH_CMYK
-  int i;
-
-  for (i = 0; i < 256; ++i) {
+  for (int i = 0; i < 256; ++i) {
     cmykTransferC[i] = 255 - rgbTransferR[255 - i];
     cmykTransferM[i] = 255 - rgbTransferG[255 - i];
     cmykTransferY[i] = 255 - rgbTransferB[255 - i];
     cmykTransferK[i] = 255 - grayTransfer[255 - i];
   }
-  for (i = 0; i < 256; ++i) {
+  for (int i = 0; i < 256; ++i) {
     deviceNTransfer[0][i] = 255 - rgbTransferR[255 - i];
     deviceNTransfer[1][i] = 255 - rgbTransferG[255 - i];
     deviceNTransfer[2][i] = 255 - rgbTransferB[255 - i];
     deviceNTransfer[3][i] = 255 - grayTransfer[255 - i];
   }
-#endif
   memcpy(rgbTransferR, red, 256);
   memcpy(rgbTransferG, green, 256);
   memcpy(rgbTransferB, blue, 256);
