@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2006, 2010 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2010, 2019, 2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Tomas Are Haavet <tomasare@gmail.com>
 // Copyright (C) 2009, 2011-2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
@@ -27,6 +27,8 @@
 #ifndef SPLASHTYPES_H
 #define SPLASHTYPES_H
 
+#include <cstddef>
+
 //------------------------------------------------------------------------
 // coordinates
 //------------------------------------------------------------------------
@@ -59,16 +61,13 @@ enum SplashColorMode {
 				//   RGBRGB...
   splashModeBGR8,		// 1 byte per component, 3 bytes per pixel:
 				//   BGRBGR...
-  splashModeXBGR8		// 1 byte per component, 4 bytes per pixel:
+  splashModeXBGR8,		// 1 byte per component, 4 bytes per pixel:
 				//   XBGRXBGR...
-#ifdef SPLASH_CMYK
-  ,
   splashModeCMYK8,	// 1 byte per component, 4 bytes per pixel:
 				//   CMYKCMYK...
   splashModeDeviceN8		// 1 byte per component, 
                         // 4 bytes + n bytes spot colors per pixel:
 				                // CMYKSSSSCMYKSSSS...
-#endif
 };
 
 enum SplashThinLineMode {
@@ -82,14 +81,11 @@ enum SplashThinLineMode {
 extern int splashColorModeNComps[];
 
 // max number of components in any SplashColor
-#ifdef SPLASH_CMYK
-#define splashMaxColorComps SPOT_NCOMPS+4
-#else
-#define splashMaxColorComps 4
-#endif
+constexpr std::size_t splashMaxColorComps = SPOT_NCOMPS+4;
 
 typedef unsigned char SplashColor[splashMaxColorComps];
 typedef unsigned char *SplashColorPtr;
+typedef const unsigned char *SplashColorConstPtr;
 
 // RGB8
 static inline unsigned char splashRGB8R(SplashColorPtr rgb8) { return rgb8[0]; }
@@ -101,7 +97,6 @@ static inline unsigned char splashBGR8R(SplashColorPtr bgr8) { return bgr8[2]; }
 static inline unsigned char splashBGR8G(SplashColorPtr bgr8) { return bgr8[1]; }
 static inline unsigned char splashBGR8B(SplashColorPtr bgr8) { return bgr8[0]; }
 
-#ifdef SPLASH_CMYK
 // CMYK8
 static inline unsigned char splashCMYK8C(SplashColorPtr cmyk8) { return cmyk8[0]; }
 static inline unsigned char splashCMYK8M(SplashColorPtr cmyk8) { return cmyk8[1]; }
@@ -114,39 +109,39 @@ static inline unsigned char splashDeviceN8M(SplashColorPtr deviceN8) { return de
 static inline unsigned char splashDeviceN8Y(SplashColorPtr deviceN8) { return deviceN8[2]; }
 static inline unsigned char splashDeviceN8K(SplashColorPtr deviceN8) { return deviceN8[3]; }
 static inline unsigned char splashDeviceN8S(SplashColorPtr deviceN8, int nSpot) { return deviceN8[4 + nSpot]; }
-#endif
 
 static inline void splashClearColor(SplashColorPtr dest) {
   dest[0] = 0;
   dest[1] = 0;
   dest[2] = 0;
-#ifdef SPLASH_CMYK
   dest[3] = 0;
   for (int i = 4; i < SPOT_NCOMPS + 4; i++)
     dest[i] = 0;
-#endif
 }
 
-static inline void splashColorCopy(SplashColorPtr dest, SplashColorPtr src) {
+static inline void splashColorCopy(SplashColorPtr dest, SplashColorConstPtr src) {
   dest[0] = src[0];
   dest[1] = src[1];
   dest[2] = src[2];
-#ifdef SPLASH_CMYK
   dest[3] = src[3];
   for (int i = 4; i < SPOT_NCOMPS + 4; i++)
     dest[i] = src[i];
-#endif
 }
 
-static inline void splashColorXor(SplashColorPtr dest, SplashColorPtr src) {
+static inline bool splashColorEqual(SplashColorConstPtr dest, SplashColorConstPtr src) {
+  for (int i = 0; i < SPOT_NCOMPS + 4; i++)
+    if (dest[i] != src[i])
+        return false;
+  return true;
+}
+
+static inline void splashColorXor(SplashColorPtr dest, SplashColorConstPtr src) {
   dest[0] ^= src[0];
   dest[1] ^= src[1];
   dest[2] ^= src[2];
-#ifdef SPLASH_CMYK
   dest[3] ^= src[3];
   for (int i = 4; i < SPOT_NCOMPS + 4; i++)
     dest[i] ^= src[i];
-#endif
 }
 
 //------------------------------------------------------------------------
