@@ -75,7 +75,7 @@ int main (int argc, char *argv[])
   }
 
   // load input document
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
   doc = new PDFDoc(inputName, ownerPW, userPW);
   if (!doc->isOk()) {
     fprintf(stderr, "Error loading input document\n");
@@ -107,7 +107,6 @@ int main (int argc, char *argv[])
 done:
   delete docOut;
   delete doc;
-  delete globalParams;
   delete userPW;
   delete ownerPW;
   return res;
@@ -247,9 +246,9 @@ static bool compareObjects(const Object *objA, const Object *objB)
       if (objB->getType() != objRef) {
         return false;
       } else {
-        Ref refA = objA->getRef();
-        Ref refB = objB->getRef();
-        return (refA.num == refB.num) && (refA.gen == refB.gen);
+        const Ref refA = objA->getRef();
+        const Ref refB = objB->getRef();
+        return refA == refB;
       }
     }
     default:
