@@ -19,7 +19,7 @@
 // Copyright (C) 2010 Jakob Voss <jakob.voss@gbv.de>
 // Copyright (C) 2012, 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
-// Copyright (C) 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018, 2019 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -31,7 +31,7 @@
 
 #include "poppler/poppler-config.h"
 
-#include <stdio.h>
+#include <cstdio>
 #include "goo/ImgWriter.h"
 #include "OutputDev.h"
 
@@ -66,7 +66,7 @@ public:
   ImageOutputDev(char *fileRootA, bool pageNamesA, bool listImagesA);
 
   // Destructor.
-  virtual ~ImageOutputDev();
+  ~ImageOutputDev() override;
 
   // Use PNG format for output
   void enablePNG(bool png) { outputPNG = png; }
@@ -127,7 +127,7 @@ public:
 		     bool interpolate, bool inlineImg) override;
   void drawImage(GfxState *state, Object *ref, Stream *str,
 		 int width, int height, GfxImageColorMap *colorMap,
-		 bool interpolate, int *maskColors, bool inlineImg) override;
+		 bool interpolate, const int *maskColors, bool inlineImg) override;
   void drawMaskedImage(GfxState *state, Object *ref, Stream *str,
 		       int width, int height,
 		       GfxImageColorMap *colorMap,
