@@ -7,12 +7,14 @@
 // Copyright (C) 2011-2015, 2017 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2012 Arseny Solokha <asolokha@gmx.com>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
-// Copyright (C) 2012, 2014, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2012, 2014, 2017-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2015 Arthur Stavisky <vovodroid@gmail.com>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Marek Kasik <mkasik@redhat.com>
+// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 //========================================================================
 
@@ -47,16 +49,16 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
     Array *newNameArray = new Array(srcXRef);
     int j = 0;
     for (int i = 0; i < srcNameArray.arrayGetLength() - 1; i += 2) {
-      Object key = srcNameArray.arrayGetNF(i);
-      Object value = srcNameArray.arrayGetNF(i + 1);
+      const Object &key = srcNameArray.arrayGetNF(i);
+      const Object &value = srcNameArray.arrayGetNF(i + 1);
       if (key.isString() && value.isRef()) {
         while (j < mergeNameArray.arrayGetLength() - 1) {
-          Object mkey = mergeNameArray.arrayGetNF(j);
-          Object mvalue = mergeNameArray.arrayGetNF(j + 1);
+          const Object &mkey = mergeNameArray.arrayGetNF(j);
+          const Object &mvalue = mergeNameArray.arrayGetNF(j + 1);
           if (mkey.isString() && mvalue.isRef()) {
             if (mkey.getString()->cmp(key.getString()) < 0) {
               newNameArray->add(Object(new GooString(mkey.getString()->c_str())));
-              newNameArray->add(Object(mvalue.getRef().num + numOffset, mvalue.getRef().gen));
+              newNameArray->add(Object( { mvalue.getRef().num + numOffset, mvalue.getRef().gen } ));
               j += 2;
             } else if (mkey.getString()->cmp(key.getString()) == 0) {
               j += 2;
@@ -68,15 +70,15 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
           }
         }
         newNameArray->add(Object(new GooString(key.getString()->c_str())));
-        newNameArray->add(Object(value.getRef().num, value.getRef().gen));
+        newNameArray->add(Object(value.getRef()));
       }
     }
     while (j < mergeNameArray.arrayGetLength() - 1) {
-      Object mkey = mergeNameArray.arrayGetNF(j);
-      Object mvalue = mergeNameArray.arrayGetNF(j + 1);
+      const Object &mkey = mergeNameArray.arrayGetNF(j);
+      const Object &mvalue = mergeNameArray.arrayGetNF(j + 1);
       if (mkey.isString() && mvalue.isRef()) {
         newNameArray->add(Object(new GooString(mkey.getString()->c_str())));
-        newNameArray->add(Object(mvalue.getRef().num + numOffset, mvalue.getRef().gen));
+        newNameArray->add(Object( { mvalue.getRef().num + numOffset, mvalue.getRef().gen } ));
       }
       j += 2;
     }
@@ -85,11 +87,11 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
   } else if (srcNameArray.isNull() && mergeNameArray.isArray()) {
     Array *newNameArray = new Array(srcXRef);
     for (int i = 0; i < mergeNameArray.arrayGetLength() - 1; i += 2) {
-      Object key = mergeNameArray.arrayGetNF(i);
-      Object value = mergeNameArray.arrayGetNF(i + 1);
+      const Object &key = mergeNameArray.arrayGetNF(i);
+      const Object &value = mergeNameArray.arrayGetNF(i + 1);
       if (key.isString() && value.isRef()) {
         newNameArray->add(Object(new GooString(key.getString()->c_str())));
-        newNameArray->add(Object(value.getRef().num + numOffset, value.getRef().gen));
+        newNameArray->add(Object( { value.getRef().num + numOffset, value.getRef().gen } ));
       }
     }
     srcNameTree->add("Names", Object(newNameArray));
@@ -117,8 +119,8 @@ static void doMergeFormDict(Dict *srcFormDict, Dict *mergeFormDict, int numOffse
   Object mergeFields = mergeFormDict->lookup("Fields");
   if (srcFields.isArray() && mergeFields.isArray()) {
     for (int i = 0; i < mergeFields.arrayGetLength(); i++) {
-      Object value = mergeFields.arrayGetNF(i);
-      srcFields.arrayAdd(Object(value.getRef().num + numOffset, value.getRef().gen));
+      const Object &value = mergeFields.arrayGetNF(i);
+      srcFields.arrayAdd(Object( { value.getRef().num + numOffset, value.getRef().gen } ));
     }
   }
 }
@@ -131,9 +133,9 @@ int main (int argc, char *argv[])
 ///////////////////////////////////////////////////////////////////////////
 {
   int objectsCount = 0;
-  Guint numOffset = 0;
+  unsigned int numOffset = 0;
   std::vector<Object> pages;
-  std::vector<Guint> offsets;
+  std::vector<unsigned int> offsets;
   XRef *yRef, *countRef;
   FILE *f;
   OutStream *outStr;
@@ -160,12 +162,13 @@ int main (int argc, char *argv[])
     return exitCode;
   }
   exitCode = 0;
-  globalParams = new GlobalParams();
+  globalParams = std::make_unique<GlobalParams>();
 
   for (i = 1; i < argc - 1; i++) {
     GooString *gfileName = new GooString(argv[i]);
     PDFDoc *doc = new PDFDoc(gfileName, nullptr, nullptr, nullptr);
-    if (doc->isOk() && !doc->isEncrypted()) {
+    if (doc->isOk() && !doc->isEncrypted() &&
+        doc->getXRef()->getCatalog().isDict()) {
       docs.push_back(doc);
       if (doc->getPDFMajorVersion() > majorVersion) {
         majorVersion = doc->getPDFMajorVersion();
@@ -176,8 +179,13 @@ int main (int argc, char *argv[])
         }
       }
     } else if (doc->isOk()) {
-      error(errUnimplemented, -1, "Could not merge encrypted files ('{0:s}')", argv[i]);
-      return -1;
+      if (doc->isEncrypted()) {
+        error(errUnimplemented, -1, "Could not merge encrypted files ('{0:s}')", argv[i]);
+        return -1;
+      } else if (!doc->getXRef()->getCatalog().isDict()) {
+        error(errSyntaxError, -1, "XRef's Catalog is not a dictionary ('{0:s}')", argv[i]);
+        return -1;
+      }
     } else {
       error(errSyntaxError, -1, "Could not merge damaged documents ('{0:s}')", argv[i]);
       return -1;
@@ -204,12 +212,12 @@ int main (int argc, char *argv[])
     Object catObj = docs[0]->getXRef()->getCatalog();
     Dict *catDict = catObj.getDict();
     intents = catDict->lookup("OutputIntents");
-    afObj = catDict->lookupNF("AcroForm");
+    afObj = catDict->lookupNF("AcroForm").copy();
     Ref *refPage = docs[0]->getCatalog()->getPageRef(1);
     if (!afObj.isNull() && refPage) {
       docs[0]->markAcroForm(&afObj, yRef, countRef, 0, refPage->num, refPage->num);
     }
-    ocObj = catDict->lookupNF("OCProperties");
+    ocObj = catDict->lookupNF("OCProperties").copy();
     if (!ocObj.isNull() && ocObj.isDict() && refPage) {
       docs[0]->markPageObjects(ocObj.getDict(), yRef, countRef, 0, refPage->num, refPage->num);
     }
@@ -287,7 +295,7 @@ int main (int argc, char *argv[])
 	    docs[i]->getCatalog()->getPage(j)->getRotate(),
 	    docs[i]->getCatalog()->getPage(j)->getMediaBox(), cropBox);
       Ref *refPage = docs[i]->getCatalog()->getPageRef(j);
-      Object page = docs[i]->getXRef()->fetch(refPage->num, refPage->gen);
+      Object page = docs[i]->getXRef()->fetch(*refPage);
       Dict *pageDict = page.getDict();
       Object *resDict = docs[i]->getCatalog()->getPage(j)->getResourceDictObject();
       if (resDict->isDict()) {
@@ -296,7 +304,7 @@ int main (int argc, char *argv[])
       pages.push_back(std::move(page));
       offsets.push_back(numOffset);
       docs[i]->markPageObjects(pageDict, yRef, countRef, numOffset, refPage->num, refPage->num);
-      Object annotsObj = pageDict->lookupNF("Annots");
+      Object annotsObj = pageDict->lookupNF("Annots").copy();
       if (!annotsObj.isNull()) {
         docs[i]->markAnnotations(&annotsObj, yRef, countRef, numOffset, refPage->num, refPage->num);
       }
@@ -313,7 +321,7 @@ int main (int argc, char *argv[])
     Object pageForm = pageCatDict->lookup("AcroForm");
     if (i > 0 && !pageForm.isNull() && pageForm.isDict()) {
       if (afObj.isNull()) {
-        afObj = pageCatDict->lookupNF("AcroForm");
+        afObj = pageCatDict->lookupNF("AcroForm").copy();
       } else if (afObj.isDict()) {
         doMergeFormDict(afObj.getDict(), pageForm.getDict(), numOffset);
       }
@@ -372,7 +380,7 @@ int main (int argc, char *argv[])
       if (j > 0)
 	outStr->printf(" ");
       const char *key = pageDict->getKey(j);
-      Object value = pageDict->getValNF(j);
+      Object value = pageDict->getValNF(j).copy();
       if (strcmp(key, "Parent") == 0) {
         outStr->printf("/Parent %d 0 R", rootNum + 1);
       } else {
@@ -398,6 +406,5 @@ int main (int argc, char *argv[])
   delete yRef;
   delete countRef;
   for (i = 0; i < (int) docs.size (); i++) delete docs[i];
-  delete globalParams;
   return exitCode;
 }
